
package com.quest.sample.pluggable.action;

import com.quest.nitro.service.action.api.*;
import com.quest.nitro.service.sl.interfaces.lifecycle.LifecycleAware;
import com.quest.nitro.service.sl.interfaces.lifecycle.LifecycleException;

import javax.management.ObjectName;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Map;

/**
 * A sample action MBean implementation for print a message on the standard
 * output.
 */
public class SampleAction extends BaseAction implements SampleActionMBean, LifecycleAware {

@Override
public void start() throws LifecycleException {
	try {
		getServer().registerMBean(this, new ObjectName(getServiceName()));
	}
	catch (Exception e) {
		throw new LifecycleException("Could not register MBean " + getServiceName(), e);
	}

}

private String getServiceName() {
	return NAME_ROOT + getClass().getSimpleName();
}

@Override
public void stop() throws LifecycleException {
	try {
		getServer().unregisterMBean(new ObjectName(getServiceName()));
	}
	catch (Exception e) {
		throw new LifecycleException("Could not unregister MBean " + getServiceName(), e);
	}
}

/**
 * Implementation for providing meta data
 */
@Override
public Collection<ActionParameterMetaData> getParametersMetadata() {
	Collection<ActionParameterMetaData> result = new ArrayList<ActionParameterMetaData>();
	ActionParameterMetaData log = new SimpleActionParameterMetaData("name", String.class,
			"Say hi to whom", true, "Quest");
	result.add(log);
	return result;
}

/**
 * Implementation for action invocation
 */
@Override
public void invoke(Map<String, ActionParameter> parameters) throws ActionInvocationException {
	System.out.println("Hi - " + parameters.get("name").getValue());
}

@Override
public boolean isExternal() {
	return true;
}

}